@@ -1,7 +1,8 @@
-import htmlgenerator as hg
 from bread import layout
+from bread.layout.components.icon import Icon
 from django.utils.translation import gettext_lazy as _
 
+from basxconnect.core import models
 from basxconnect.core.layouts import editperson
 
 R = layout.grid.Row
@@ -13,25 +14,26 @@ def editpersonassociation_form(request):
     return editperson.editperson_form(request, base_data_tab, mailings_tab)
 
 
-def base_data_tab():
+def base_data_tab(request):
     return layout.tabs.Tab(
         _("Base data"),
         editperson.grid_inside_tab(
-            editperson.tiling_row(
-                R(
-                    C(hg.H4(_("General Information"))),
-                ),
-                R(
-                    C(
-                        R(
-                            C(F("name"), width=4),
-                            C(F("preferred_language"), width=2),
-                            C(F("salutation_letter"), width=4),
-                        ),
-                    ),
+            R(
+                editperson.tile_col_edit_modal(
+                    _("Base Data"),
+                    models.PersonAssociation,
+                    "ajax_edit",
+                    Icon("building"),
+                    [
+                        "name",
+                        "preferred_language",
+                        "salutation_letter",
+                    ],
                 ),
+                editperson.person_metadata(models.LegalPerson),
             ),
-            editperson.contact_details(),
+            editperson.contact_details(request),
+            R(editperson.categories(), editperson.other()),
         ),
     )
 
