@@ -15,7 +15,6 @@ from basxconnect.core.views import menu_views
 from basxconnect.mailer_integration import download_data
 from basxconnect.mailer_integration.abstract.abstract_datasource import MailerPerson
 from basxconnect.mailer_integration.mailchimp import datasource
-from basxconnect.mailer_integration.models import MailingPreferences
 
 
 @aslayout
@@ -28,7 +27,14 @@ def mailchimp_view(request):
             notification = bread.layout.components.notification.InlineNotification(
                 "Success",
                 f"Synchronized mailing preferences for {sync_result.total_synchronized_persons} Mailchimp "
-                f"contacts. {sync_result.new_persons} new persons were added to the BasxConnect database.",
+                f"contacts. {sync_result.new_persons} new persons were added to the BasxConnect database. "
+                + (
+                    "The following mailchimp contacts are not yet in our database but were also not "
+                    "added because they were invalid:"
+                    ", ".join(sync_result.invalid_new_persons)
+                    if len(sync_result.invalid_new_persons) > 0
+                    else ""
+                ),
             )
         except Exception:
             notification = bread.layout.components.notification.InlineNotification(
